function [W]=ChooseDrawingBox(V,cfinite)
% 
% Функция ChooseDrawingBox выбирает брус обрезки-отрисовки W так, 
% чтобы он содержал все точки - строки матрицы V.
% Входной аргумент cfinite может иметь значения
% 0 (множество неограниченно) или 1 (ограниченно).
% Он позволяет варьировать выбор бруса обрезки-отрисовки в зависимости 
% от того, ограниченно ли множество, которое надо нарисовать.

%% Во всех матрицах этого файла первый столбец - абсцисса, 
%% второй - ордината, третий - аппликата.
%% В ihV и W первая строка - нижний конец, вторая - верхний конец 
%% соответствующего бруса.

   % Найдем интервальную оболочку точек из V.
   ihV=[min(V(:,1))  min(V(:,2)) min(V(:,3)); max(V(:,1)) max(V(:,2)) max(V(:,3))];
   center=(ihV(1,:)+ihV(2,:))/2;
   radius=(ihV(2,:)-ihV(1,:))/2;
   rm=max(radius);

   % Выберем брус обрезки-отрисовки чуть шире интервальной оболочки.
   % Выбор зависит от наличия у интервальной оболочки вырожденных компонент.
   if isequal(ihV(1,:),ihV(2,:)) % все компоненты вырождены
      W=[center-1; center+1];
   else                          % есть невырожденные компоненты
      W=[center-1.2*rm; center+1.2*rm];
   end

   % Если рисуемое множество неограниченно, увеличим брус обрезки-отрисовки W.
   % (Это улучшает восприятие неограниченности.)
   if ~cfinite
      radius=(W(2,:)-W(1,:))/2;
      W=W+2*[-radius; radius];
   end

end