function [A,b,cnmty] = ClearZeroRows(A,b)
%
% Функция ClearZeroRows пересматривает строки 
% системы линейных неравенств Ax >= b, где  
%   A - прямоугольная вещественная матрица, 
%   b - вектор с элементами из расширенной числовой прямой,
%   x - вещественный вектор неизвестных,
% и удаляет из этой системы те строки, которые соответствуют
% нулевым строкам матрицы A.
%
% Выход - 
%   новая система неравенств Ax >= b (новые матрица A и вектор b),
%   и параметр cnmty (Control of NoneMpTiness).
%   Параметр cnmty принимает значения:
%     false - исходная система несовместна 
%            (т.е множество ее решений пусто),
%     true - исходная система возможно совместна 
%            (т.е. множество ее решений может быть непустым).
%   Для  cnmty = true  важно, что: 
%     1) новая система эквивалентна исходной,
%     2) если в новой системе строк не осталось, 
%        то множество решений исходной системы совпадает 
%        со всем пространством. 

   [m,n] = size(A);
   cnmty = true;
   p = [];

   for i=1:m
%      if single(A(i,:)) == zeros(1,n)
      if max(abs(A(i,:)))<1.e-8
         p = [p i];
%         if 0 < b(i)
         if b(i)>1e-12
            cnmty = false;
         end
      end
    end
    
    A(p,:) = [];
    b(p,:) = [];
                
end                
