function [V]=LeqQtrR3(infA,supA,Aq,infb,supb,bq,OrientPoints,transparency,varargin)
%
% Функция LeqQtrR3 рисует множество кванторных решений 
% для интервальной системы линейных неравенств  A x <= b, где
%   A - интервальная матрица, у которой m строк и 3 столбца;
%   b - интервальный вектор длины m;
% а также вычисляет вершины пересечений этого множества решений с ортантами.
%
% Обязательные входные аргументы:
%   infA, supA - нижний и верхний концы матрицы A - вещественные матрицы;
%   Aq - матрица из букв 'A' и 'E' (набирать на английском языке),
%     которые соответствуют кванторам всеобщности и существования 
%     в описании кванторного решения;
%     размер матриц infA, supA и Aq такой же как размер матрицы A 
%     (m строк и 3 столбца);
%   infb, supb - нижний и верхний концы вектора b - вещественные векторы длины m;
%   bq - вектор длины m из букв 'A' и 'E' (назначение букв как в Aq);
%   OrientPoints - параметр для рисования точек-ориентиров, 
%     его значения: 0 - не рисуем, 1 - рисуем;
%   transparency - параметр прозрачности реальных граней, 
%     его значения: 0 - непрозрачные, 1 - прозрачные.
%
% Дополнительные входные аргументы:
%   varargin - брус принудительной обрезки, 
%     вводится как 6 чисел  xb,xe,yb,ye,zb,ze, где 
%     xb,yb,zb - нижний конец, а  xe,ye,ze - верхний конец бруса.
%
% Выходные аргументы: 
%   V - список точек-ориентиров 
%     (вершин пересечений множества решений с ортантами).
%
% автор: Шарая Ирина Александровна (Институт вычислительных технологий, Новосибирск)
% дата:  03/04/2013

   % перейдем к интервальному включению [uC,oC] x \subseteq [ud,od]
   % в арифметике Каухера
   m=size(Aq,1);
   uC=infA; 
   oC=supA;
   Aqe=[Aq==ones(m,3)*'E'];
   uC(Aqe)=supA(Aqe);
   oC(Aqe)=infA(Aqe);
%   ud=infb; 
   od=supb; 
   bqa=[bq==ones(m,1)*'A'];
%   ud(bqa)=supb(bqa);
   ud=-ones(m,1)*Inf;
   od(bqa)=infb(bqa);

   % нарисуем множество решений включения [uC,oC] x \subseteq [ud,od]
   var=(length(varargin)==6);
   if var % если пользователь задал брус как дополнительный аргумент, 
      [V]=CxindR3(uC,oC,ud,od,OrientPoints,transparency,varargin{1},varargin{2},varargin{3},varargin{4},varargin{5},varargin{6});
   else
      [V]=CxindR3(uC,oC,ud,od,OrientPoints,transparency);
   end

end                
